@@ -1,7 +1,30 @@
 #!/usr/bin/env python3
+"""
+## Show example usage and example output.
+
+```py
+from iometrics.example import usage
+usage()
+```
+
+Example output
+
+```markdown
+|        Network (MBytes/s)       | Disk Util |            Disk MBytes          |           Disk I/O          |
+|     Received    |     Sent      |     %     |    MB/s Read    |  MB/s Written |     I/O Read    | I/O Write |
+|   val  |   avg  |  val  |  avg  | val | avg |  val   |  avg   |  val  |  avg  |   val  |   avg  | val | avg |
+| ------:| ------:| -----:| -----:| ---:| ---:| ------:| ------:| -----:| -----:| ------:| ------:| ---:| ---:|
+|    4.6 |    3.5 |   0.1 |   0.1 |  49 |   2 |   52.8 |    1.1 |   0.0 |   0.9 |    211 |      4 |   5 |  18 |
+|    4.1 |    3.5 |   0.1 |   0.1 |  61 |   3 |   60.4 |    2.4 |  40.3 |   1.7 |    255 |     10 | 149 |  21 |
+```
+
+:copyright: (c) 2021 by Leo Gallucci.
+:license: Apache 2.0, see LICENSE for more details.
+"""
 import time
 
-from iometrics import NetworkMetrics, DiskMetrics
+from iometrics import DiskMetrics
+from iometrics import NetworkMetrics
 
 
 DUAL_METRICS_HEADER = """
@@ -12,19 +35,8 @@ DUAL_METRICS_HEADER = """
 
 
 def usage(iterations: int = 10000) -> str:
-    """
-    ## Example usage and example output:
-
-    ```markdown
-    |        Network (MBytes/s)       | Disk Util |            Disk MBytes          |           Disk I/O          |
-    |     Received    |     Sent      |     %     |    MB/s Read    |  MB/s Written |     I/O Read    | I/O Write |
-    |   val  |   avg  |  val  |  avg  | val | avg |  val   |  avg   |  val  |  avg  |   val  |   avg  | val | avg |
-    | ------:| ------:| -----:| -----:| ---:| ---:| ------:| ------:| -----:| -----:| ------:| ------:| ---:| ---:|
-    |    4.6 |    3.5 |   0.1 |   0.1 |  49 |   2 |   52.8 |    1.1 |   0.0 |   0.9 |    211 |      4 |   5 |  18 |
-    |    4.1 |    3.5 |   0.1 |   0.1 |  61 |   3 |   60.4 |    2.4 |  40.3 |   1.7 |    255 |     10 | 149 |  21 |
-    ```
-    """
-    net  = NetworkMetrics()
+    """Compute a live metric report of network and disk statistics."""
+    net = NetworkMetrics()
     disk = DiskMetrics()
 
     for i in range(iterations):
@@ -33,7 +45,8 @@ def usage(iterations: int = 10000) -> str:
         net.update_stats()
         disk.update_stats()
 
-        print(DUAL_METRICS_HEADER) if i % 15 == 0 else None
+        if i % 15 == 0:
+            print(DUAL_METRICS_HEADER)
         row = (
             f"| {net.mb_recv_ps.val:6.1f} | {net.mb_recv_ps.avg:6.1f} "
             f"| {net.mb_sent_ps.val:5.1f} | {net.mb_sent_ps.avg:5.1f} "
@@ -48,6 +61,7 @@ def usage(iterations: int = 10000) -> str:
 
     return row
 
+
 # `__all__` is left here for documentation purposes and as a
 # reference to which interfaces are meant to be imported.
 __all__ = [
